/*
	$Id: DalMySQLDatabase.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __DalMySQLDatabase_h__
#define __DalMySQLDatabase_h__

#include <librfcdal/DalDatabase.h>
#include <librfcdal/DalDatabaseException.h>

#include <string>

#if defined (RFCDALDB_EXPORT)
#	undef RFCDALDB_EXPORT
#endif /* RFCDALDB_EXPORT */

#if defined (LINUX)
#	define RFCDALDB_EXPORT
#elif defined (_WINDOWS)
#	include <windows.h>
#	if defined (LIBRFCDALDBMYSQL_EXPORTS)
#		define RFCDALDB_EXPORT __declspec( dllexport )
#	else
#		define RFCDALDB_EXPORT __declspec( dllimport )
#	endif /* LIBRFCDAL_EXPORTS */
#endif /* LINUX */

struct st_mysql;

namespace RfcDal
{
	class RFCDALDB_EXPORT DalMySQLDatabase : public DalDatabase
	{
		private:
			struct st_mysql* _pmysql;
			st_mysql* mysqlConnection();
			static DalDatabase::ConnectionParameterList _parameterS;

		public:
			DalMySQLDatabase();
			virtual ~DalMySQLDatabase();

			bool connect( const std::string& strHost, const std::string& strDatabase,
							const std::string& strUserId, const std::string& strPassword, int nPort = 0 );
			bool connect( const std::string& strHost, const std::string& strDatabase,
							const std::string& strUserId, const std::string& strPassword, const std::string& strSocket );
			virtual const ConnectionParameterList& connectionParameters() const;
			virtual bool connectX( const std::string& strConnect, ConnectionParameterMap& map = _mapDefault );
			virtual bool connectX( ConnectionParameterMap& map );
			virtual void disconnect();

			virtual unsigned execute( const SqlModifyStatement& statement );
			virtual unsigned execute( Result& result, const SqlQueryStatement& statement, SqlQueryInfo* pinfo = NULL );

			virtual bool autoCommit();
			virtual void setAutoCommit( bool bOn );
			virtual void begin();
			virtual void commit();
			virtual void rollback();

			virtual void schemas( SqlSchemaList& schemaS, const SqlDatabase& catalog );
			virtual void tables( SqlTableList& tableS, const SqlSchema& schema );
			virtual void invoke( SqlQueryInfo& info, const SqlTable& table );

		private:
			DalMySQLDatabase( const DalMySQLDatabase& );
			const DalMySQLDatabase& operator=( const DalMySQLDatabase& );
	};
};

#endif /* !__DalMySQLDatabase_h__ */
